@@ -5,11 +5,11 @@ Created on Sun Jun 13 17:48:10 2021
 @author: Vishwesh
 """
 import numpy as np
-from basic_gates import OR, AND
-from plotting import plot_basic
-from combinational_gates import *
-from Logic_circuits import *
-from arithmatic_gates import *
+from Logic_Py.basic_gates import OR, AND
+from Logic_Py.plotting import plot_basic
+from Logic_Py.combinational_gates import *
+from Logic_Py.Logic_circuits import *
+from Logic_Py.arithmatic_gates import *
 w = [1,1,0,1,1,0,0,1,0,0]
 x = [0,0,0,1,0,1,1,0,1,1]
 y = [0,1,0,1,0,1,0,0,0,0]
@@ -32,8 +32,8 @@ q,p,r,s = Excess32BCD(w,x,y,z)
 plot_basic(x, y, AND)
 
 #%%
-from arithmatic_gates import full_adder
-from plotting import plot_full_adder
+from Logic_Py.arithmatic_gates import full_adder
+from Logic_Py.plotting import plot_full_adder
 
 sum_,carry_ = full_adder(x, y,z)
 plot_full_adder(x,y,z)
